package Net::HTTP2::Client::Mojo;

use strict;
use warnings;

use constant _CLIENT_IO => 'Mojo';

use parent 'Net::HTTP2::Client';

1;

